aboutsummaryrefslogtreecommitdiffstats
path: root/src/classes/javax/media/opengl/GLDrawableFactory.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2009-03-13 11:55:23 +0000
committerSven Gothel <[email protected]>2009-03-13 11:55:23 +0000
commita74f1100b11eb3a6944a73eea48bf17d14ede8c1 (patch)
tree48a1d2e9fb9a7beb0c71ce016104022e79d736d3 /src/classes/javax/media/opengl/GLDrawableFactory.java
parent3f0266e5d20216f68f515a943ad647d01e0ff567 (diff)
New package Native Window Interface 'java.media.nwi',
to loose JOGL dependencies for the moved interfaces, mainly NativeWindow. git-svn-id: file:///usr/local/projects/SUN/JOGL/git-svn/svn-server-sync/jogl/branches/JOGL_2_SANDBOX@1863 232f8b59-042b-4e1e-8c03-345bb8c30851
Diffstat (limited to 'src/classes/javax/media/opengl/GLDrawableFactory.java')
-rw-r--r--src/classes/javax/media/opengl/GLDrawableFactory.java32
1 files changed, 17 insertions, 15 deletions
diff --git a/src/classes/javax/media/opengl/GLDrawableFactory.java b/src/classes/javax/media/opengl/GLDrawableFactory.java
index dbbb42a0e..7ef8bdd58 100644
--- a/src/classes/javax/media/opengl/GLDrawableFactory.java
+++ b/src/classes/javax/media/opengl/GLDrawableFactory.java
@@ -39,6 +39,8 @@
package javax.media.opengl;
+import javax.media.nwi.*;
+
import java.lang.reflect.*;
import java.security.*;
import com.sun.opengl.impl.*;
@@ -46,21 +48,21 @@ import com.sun.opengl.impl.*;
/** <P> Provides a virtual machine- and operating system-independent
mechanism for creating {@link GLDrawable}s. </P>
- <P> The {@link javax.media.opengl.GLCapabilities} objects passed
+ <P> The {@link javax.media.opengl.NWCapabilities} objects passed
in to the various factory methods are used as a hint for the
properties of the returned drawable. The default capabilities
selection algorithm (equivalent to passing in a null {@link
- GLCapabilitiesChooser}) is described in {@link
- DefaultGLCapabilitiesChooser}. Sophisticated applications needing
+ NWCapabilitiesChooser}) is described in {@link
+ DefaultNWCapabilitiesChooser}. Sophisticated applications needing
to change the selection algorithm may pass in their own {@link
- GLCapabilitiesChooser} which can select from the available pixel
- formats. The GLCapabilitiesChooser mechanism may not be supported
+ NWCapabilitiesChooser} which can select from the available pixel
+ formats. The NWCapabilitiesChooser mechanism may not be supported
by all implementations or on all platforms, in which case any
- passed GLCapabilitiesChooser will be ignored. </P>
+ passed NWCapabilitiesChooser will be ignored. </P>
<P> Because of the multithreaded nature of the Java platform's
Abstract Window Toolkit, it is typically not possible to immediately
- reject a given {@link GLCapabilities} as being unsupportable by
+ reject a given {@link NWCapabilities} as being unsupportable by
either returning <code>null</code> from the creation routines or
raising a {@link GLException}. The semantics of the rejection
process are (unfortunately) left unspecified for now. The current
@@ -153,19 +155,19 @@ public abstract class GLDrawableFactory {
* Returns a GLDrawable that wraps a platform-specific window system
* object, such as an AWT or LCDUI Canvas. On platforms which
* support it, selects a pixel format compatible with the supplied
* GLCapabilities, or if the passed GLCapabilities object is null,
* uses a default set of capabilities. On these platforms, uses
* either the supplied GLCapabilitiesChooser object, or if the
* passed GLCapabilitiesChooser object is null, uses a
* DefaultGLCapabilitiesChooser instance.
*
* @throws IllegalArgumentException if the passed target is null
* @throws GLException if any window system-specific errors caused
* the creation of the GLDrawable to fail.
*/
public abstract GLDrawable createGLDrawable(NativeWindow target,
- GLCapabilities capabilities,
- GLCapabilitiesChooser chooser)
+ NWCapabilities capabilities,
+ NWCapabilitiesChooser chooser)
throws IllegalArgumentException, GLException;
//----------------------------------------------------------------------
@@ -186,8 +188,8 @@ public abstract class GLDrawableFactory {
* @throws GLException if any window system-specific errors caused
* the creation of the GLPbuffer to fail.
*/
- public abstract GLPbuffer createGLPbuffer(GLCapabilities capabilities,
- GLCapabilitiesChooser chooser,
+ public abstract GLPbuffer createGLPbuffer(NWCapabilities capabilities,
+ NWCapabilitiesChooser chooser,
int initialWidth,
int initialHeight,
GLContext shareWith)
@@ -153,19 +155,19 @@ public abstract class GLDrawableFactory {
* object, such as an AWT or LCDUI Canvas. On platforms which
* support it, selects a pixel format compatible with the supplied
- * GLCapabilities, or if the passed GLCapabilities object is null,
+ * NWCapabilities, or if the passed NWCapabilities object is null,
* uses a default set of capabilities. On these platforms, uses
@@ -153,19 +155,19 @@ public abstract class GLDrawableFactory {
* uses a default set of capabilities. On these platforms, uses
- * either the supplied GLCapabilitiesChooser object, or if the
- * passed GLCapabilitiesChooser object is null, uses a
- * DefaultGLCapabilitiesChooser instance.
+ * either the supplied NWCapabilitiesChooser object, or if the
+ * passed NWCapabilitiesChooser object is null, uses a
+ * DefaultNWCapabilitiesChooser instance.
*
* @throws IllegalArgumentException if the passed target is null